classify

Function classify 

fn classify<'gcx>(gcx: Gcx<'gcx>, callee: &Expr<'gcx>) -> Option<ExternalCall>
Classifies calls by their checked function kind, including function pointers and library delegate calls. Internal using for bindings and super dispatch stay internal.